@@ -68,9 +68,16 @@ class Yaml_Config(object):
         sessionstore_name = self.settings.get('session_store', 'MemorySessionStore')
         module = __import__('torweb.sessions', {}, {}, sessionstore_name) 
         cls =  getattr(module, sessionstore_name)
+        print 'session store: %s' % cls.__name__
         if cls.__name__ == 'MemcachedSessionStore':
             #print 'session store: %s' % cls.__name__
             return cls(self.settings.get('memcached', ['127.0.0.1:11211']))
+        if cls.__name__ == 'RedisSessionStore':
+            _redis = self.settings.get("redis", {})
+            import redis
+            redis_conn = redis.StrictRedis(host=_redis.get("host", "127.0.0.1"), port=_redis.get("port", "6379"), db="test")
+            #return cls(redis.get("host", "127.0.0.1"), redis.get("port", "6379"))
+            return cls(redis_conn, key_prefix=_redis.get("prefix", "session"), expire=_redis.get("expire", 3600))
         if cls.__name__ == 'MemorySessionStore':
             #print 'session store: %s' % cls.__name__
             return cls()
